@@ -1,3 +1,4 @@
+import re
 from abc import ABC
 from typing import Optional
 
@@ -10,7 +11,7 @@ __all__ = ["JAVLibrary"]
 class JAVLibrary(Base, ABC):
 
     def __init__(self, region: str = "en"):
-        super().__init__(base_url="http://www.javlibrary.com")
+        super().__init__(base_url="https://www.javlibrary.com")
         self.region: str = region
 
         self._set_cookies({"over18": "18"})
@@ -23,7 +24,8 @@ class JAVLibrary(Base, ABC):
             "image": self._fix_image,
             "actresses": "//span[@class='star']/a",
             "genres": "//span[@class='genre']/a",
-            "release_date": "//div[@id='video_date']/table/tr/td[2]"
+            "release_date": "//div[@id='video_date']/table/tr/td[2]",
+            "score": self._fix_score
         })
 
     def _build_search_path(self, query: str) -> str:
@@ -33,6 +35,9 @@ class JAVLibrary(Base, ABC):
         video_url = self.search(query)
         if len(video_url) == 0:
             return None
+
+        if self.debug:
+            print(f"Found video {video_url[0]}")
         return video_url[0]
 
     @staticmethod
@@ -45,3 +50,11 @@ class JAVLibrary(Base, ABC):
         value = tree.xpath("//h3[contains(@class, 'post-title')]")[0].text_content()
         code = tree.xpath("//div[@id='video_id']/table/tr/td[2]")[0].text_content()
         return value.replace(code, "").strip()
+
+    @staticmethod
+    def _fix_score(url: str, tree) -> float:
+        value = tree.xpath("//div[@id='video_review']//span/text()")
+        if not value:
+            return 0.0
+
+        return float(re.search(r"\(([0-9.]+)\)", "".join(value)).group(1))
