@@ -22,11 +22,12 @@ class MGStage(Base, ABC):
             "code": self._fix_code,
             "studio": "//tr[th='メーカー：']/td/a",
             "image": self._fix_image,
-            "actresses": "//tr[th='出演：']/td/a",
+            "actresses": self._fix_actresses,
             "genres": "//tr[th='ジャンル：']/td/a",
             "release_date": "//tr[th='配信開始日：']/td",
             "description": "//p[contains(@class, 'introduction')]",
-            "sample_video": self._fix_sample_video
+            "sample_video": self._fix_sample_video,
+            "score": self._fix_score
         })
 
     def _build_search_path(self, query: str) -> str:
@@ -44,6 +45,13 @@ class MGStage(Base, ABC):
     def _fix_code(url: str, tree) -> str:
         return re.search(r"product_detail/([a-zA-Z0-9-_]*)", url).group(1)
 
+    @staticmethod
+    def _fix_actresses(url: str, tree) -> list:
+        found = tree.xpath("//tr[th='出演：']/td/a")
+        if found:
+            return [x.text_content().strip() for x in found]
+        return []
+
     @staticmethod
     def _fix_image(url: str, tree) -> str:
         return tree.xpath("//a[@id='EnlargeImage']")[0].get("href")
@@ -71,3 +79,11 @@ class MGStage(Base, ABC):
                 url = url.partition(".ism")[0] + ".mp4"
                 return url
         return None
+
+    @staticmethod
+    def _fix_score(url: str, tree) -> float:
+        value = tree.xpath("//td[@class='review']/text()")
+        if not value:
+            return 0.0
+
+        return float(re.search(r"([0-9.]+)\n", "".join(value)).group(1))
